==> libtorrent-0.7.6.tar.gz: libtorrent-0.7.6/src/net/socket_stream.cc <==
// libTorrent - BitTorrent library
// Copyright (C) 2005, Jari Sundell
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations
// including the two.
//
// You must obey the GNU General Public License in all respects for
// all of the code used other than OpenSSL.  If you modify file(s)
// with this exception, you may extend this exception to your version
// of the file(s), but you are not obligated to do so.  If you do not
// wish to do so, delete this exception statement from your version.
// If you delete this exception statement from all source files in the
// program, then also delete it here.
//
// Contact:  Jari Sundell <jaris@ifi.uio.no>
//
//           Skomakerveien 33
//           3185 Skoppum, NORWAY

#include "config.h"

#include "socket_stream.h"

#include <cerrno>
#include <cstdio>
#include <cstring>
#include <sys/types.h>
#include <sys/socket.h>
#include <rak/error_number.h>

#include "torrent/exceptions.h"

namespace torrent {

std::string
int_to_string(int v) {
  char buf[20];

  std::sprintf(buf, "%i", v);

  return buf;
}

inline int
SocketStream::read_stream(void* buf, unsigned int length) {
  if (length == 0)
    throw internal_error("Tried to read buffer length 0");

  return ::recv(m_fileDesc, buf, length, 0);
}

inline int
SocketStream::write_stream(const void* buf, unsigned int length) {
  if (length == 0)
    throw internal_error("Tried to write buffer length 0");

  return ::send(m_fileDesc, buf, length, 0);
}

uint32_t
SocketStream::read_stream_throws(void* buf, uint32_t length) {
  int r = read_stream(buf, length);

  if (r == 0)
    throw close_connection();

  if (r < 0)
    if (rak::error_number::current().is_blocked_momentary())
      return 0;
    else if (rak::error_number::current().is_closed())
      throw close_connection();
    else if (rak::error_number::current().is_blocked_prolonged())
      throw blocked_connection();
    else
      throw connection_error("Connection closed due to (errno: " +
			     int_to_string(rak::error_number::current().value()) +
			     ") " +
			     std::string(rak::error_number::current().c_str()));

  return r;
}

uint32_t
SocketStream::write_stream_throws(const void* buf, uint32_t length) {
  int r = write_stream(buf, length);

  if (r == 0)
    throw close_connection();

  if (r < 0)
    if (rak::error_number::current().is_blocked_momentary())
      return 0;
    else if (rak::error_number::current().is_closed())
      throw close_connection();
    else if (rak::error_number::current().is_blocked_prolonged())
      throw blocked_connection();
    else
      throw connection_error("Connection closed due to (errno: " +
			     int_to_string(rak::error_number::current().value()) +
			     ") " +
			     std::string(rak::error_number::current().c_str()));

  return r;
}

}

==> libtorrent-0.8.5.tar.gz: libtorrent-0.8.5/src/net/socket_stream.cc <==
// libTorrent - BitTorrent library
// Copyright (C) 2005-2006, Jari Sundell
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations
// including the two.
//
// You must obey the GNU General Public License in all respects for
// all of the code used other than OpenSSL.  If you modify file(s)
// with this exception, you may extend this exception to your version
// of the file(s), but you are not obligated to do so.  If you do not
// wish to do so, delete this exception statement from your version.
// If you delete this exception statement from all source files in the
// program, then also delete it here.
//
// Contact:  Jari Sundell <jaris@ifi.uio.no>
//
//           Skomakerveien 33
//           3185 Skoppum, NORWAY

#include "config.h"

#include "socket_stream.h"

#include <cerrno>
#include <cstdio>
#include <cstring>
#include <sys/types.h>
#include <sys/socket.h>
#include <rak/error_number.h>

#include "torrent/exceptions.h"

namespace torrent {

std::string
int_to_string(int v) {
  char buf[20];

  std::sprintf(buf, "%i", v);

  return buf;
}

inline int
SocketStream::read_stream(void* buf, uint32_t length) {
  if (length == 0)
    throw internal_error("Tried to read buffer length 0");

  return ::recv(m_fileDesc, buf, length, 0);
}

inline int
SocketStream::write_stream(const void* buf, uint32_t length) {
  if (length == 0)
    throw internal_error("Tried to write buffer length 0");

  return ::send(m_fileDesc, buf, length, 0);
}

uint32_t
SocketStream::read_stream_throws(void* buf, uint32_t length) {
  int r = read_stream(buf, length);

  if (r == 0)
    throw close_connection();

  if (r < 0)
    if (rak::error_number::current().is_blocked_momentary())
      return 0;
    else if (rak::error_number::current().is_closed())
      throw close_connection();
    else if (rak::error_number::current().is_blocked_prolonged())
      throw blocked_connection();
    else
      throw connection_error("Connection closed due to (errno: " +
			     int_to_string(rak::error_number::current().value()) +
			     ") " +
			     std::string(rak::error_number::current().c_str()));

  return r;
}

uint32_t
SocketStream::write_stream_throws(const void* buf, uint32_t length) {
  int r = write_stream(buf, length);

  if (r == 0)
    throw close_connection();

  if (r < 0)
    if (rak::error_number::current().is_blocked_momentary())
      return 0;
    else if (rak::error_number::current().is_closed())
      throw close_connection();
    else if (rak::error_number::current().is_blocked_prolonged())
      throw blocked_connection();
    else
      throw connection_error("Connection closed due to (errno: " +
			     int_to_string(rak::error_number::current().value()) +
			     ") " +
			     std::string(rak::error_number::current().c_str()));

  return r;
}

}
